=====
Usage
=====

Installation::
   
   pip install myratings
   
To get ratings ::

    * Type "myratings" from the commandline
    * First time it asks for user handle of the respective sites
    * Then rating summary will be displayed


To use myratings in a project::

    import myratings

